@@ -112,13 +112,14 @@ class DBAgentClient:
         self.my_logger.error(f"set_active_run(task_id={id}) failed, status = {resp['status']}")
         raise DBAgentException(resp=resp)
 
-    def create_run(self, *, application_id, node_id, args, task_id=None):
+    def create_run(self, *, application_id, node_id, args, input=None, task_id=None):
         # args is list of strings
         req = {
             "action": "create-run",
             "application_id": application_id,
             "node_id": node_id,
-            "args": args
+            "args": args,
+            "input": input,
         }
         if task_id is not None:
             req['task_id'] = task_id
