@@ -242,7 +242,7 @@ def main():
         filename = os.path.join(run_dir, "input.txt")
         try:
             with open(filename, "wb") as tmp_f:
-                tmp_f.write(f, app_input.encode("utf-8"))
+                tmp_f.write(app_input.encode("utf-8"))
             in_f = open(filename, "rb")
             logger.info(f"{log_prefix}: input file \"{filename}\" is generated")
         except OSError as e:
